<?php

/**
 * @file
 * Sample hooks demonstrating usage in Autocomplete Attribute.
 */

/**
 * @defgroup ac_attr_hooks WCAG 2.1 Section 7: Input Purposes
 * @{
 * Autocomplete Attribute hooks enable other modules to add purposes and/or
 * default fields to a purpose.
 */

/**
 * Allow another module to add purposes for this module to manage.
 *
 * The $purposes array is a key:value array where the key is the purpose and
 * the value is the description of that purpose.
 *
 * The desctiption is used on the Defaults page.
 *
 * @param array $purposes
 *   A keyed array passed by reference.
 */
function hook_ac_attr_purposes_alter(array &$purposes) {
  $purposes += [
    'purpose' => t('Description of purpose.'),
  ];
}

/**
 * Allow another module to link fields to a purpose.
 *
 * The $fields array is a key:value array where the key is the purpose and the
 * value is an array of field_names that should get this purpose added if a
 * field of this name appears on a form we can process.
 *
 * @param array $fields
 *   An array of keyed arrays passed by reference.
 */
function hook_ac_attr_default_fields_alter(array &$fields) {
  $fields += [
    'purpose' => ['array', 'of', 'field_names'],
  ];
}

/**
 * Return fields types we can add the autocomplete attribute to.
 *
 * These are the values that appear in #type in the Form API array.
 *
 * @param array $types
 *   An array of strings passed by reference.
 */
function hook_ac_attr_field_types_alter(array &$types) {
  $types += [
    'textfield',
    'textarea',
    'webform_email',
  ];
}

/**
 * @}
 */
